@@ -44,11 +44,11 @@ RDF::LinkedData - A simple Linked Data server implementation
 
 =head1 VERSION
 
-Version 0.60
+Version 0.62
 
 =cut
 
- our $VERSION = '0.60';
+ our $VERSION = '0.62';
 
 
 =head1 SYNOPSIS
@@ -275,6 +275,10 @@ sub response {
 
 	my $headers_in = $self->request->headers;
 
+	my $server = "RDF::LinkedData/$VERSION";
+	$server .= " " . $response->headers->header('Server') if defined($response->headers->header('Server'));
+	$response->headers->header('Server' => $server);
+
 	my $endpoint_path;
 	if ($self->has_endpoint) {
 	  $endpoint_path = $self->endpoint_config->{endpoint_path};
